@@ -7,6 +7,10 @@ from colorama import Fore as __Fore
 from . import Config, Utils
 config = Config.getConfig(parentKey='core', key='Logger')
 
+
+import logging
+logging.basicConfig(filename="hackingtools.log", filemode='a', format='%(asctime)s %(levelname)s - %(message)s', datefmt='%Y-%m-%d %H:%M:%S')
+
 __colorama.init()
 
 global __logs__
@@ -64,12 +68,6 @@ def saveLog():
         for log in getLogs():
             f.write("{log}\n".format(log=log))
 
-def saveLogElasticSearch():
-    global __logs__
-    with open('hackingtools.log', 'w+') as f:
-        for log in getLogs():
-            f.write("{log}\n".format(log=log))
-
 def getLogs():
     global __logs__
     return __logs__
@@ -149,6 +147,15 @@ def printMessage(message, description=None, debug_module=False, debug_core=False
     else:
         __logs__[time_now] = msg
 
+    if is_error:
+        logging.critical(msg)
+    if is_info:
+        logging.info(msg)
+    if is_success:
+        logging.log(msg)
+    if is_warn:
+        logging.warning(msg)
+
     temp_logs_clear = {}
 
     for x in __logs__:
